# vi:fdm=marker fdl=0:
# $Id: CDX.pm,v 1.4 2003/02/08 17:16:58 jettero Exp $ 

package FoxPro::CDX;

use strict;
use Carp;
use Fcntl qw(:seek);

1;

# new and DESTROY {{{
sub new {
    my $this = shift;

    $this = bless {
        file    => shift,
    }, $this;

    croak "that's not a cdx file"        unless $this->{file} =~ m/cdx$/i;
    croak "no such file '$this->{file}'" unless -f $this->{file};

    open $this->{IN}, "$this->{file}" or croak "couldn't open $this->{file}: $!";

    $this->read_header;

    return $this;
}

sub DESTROY { 
    my $this = shift;

    close $this->{IN};
}
# }}}

sub read_header {
    my $this = shift;

    my $header;
    seek($this->{IN}, 0, SEEK_SET) or croak "bad seek: $!";
    read($this->{IN}, $header, 1024) == 1024 or die "problem reading header 1024 bytes";

    my $t;

    $this->{root_node_p} = unpack("V", substr($header, 0, 4));

    $this->{index_options}->{unique}          = ( 1 & ($t = substr($header, 14, 1)) ? 1:0);
    $this->{index_options}->{FORclause}       = ( 8 & $t ? 1:0);
    $this->{index_options}->{compact_format}  = (32 & $t ? 1:0);
    $this->{index_options}->{compound_header} = (64 & $t ? 1:0);

    print STDERR " \$this->\{index_options\}->\{unique\}          = $this->{index_options}->{unique}          \n";
    print STDERR " \$this->\{index_options\}->\{FORclause\}       = $this->{index_options}->{FORclause}       \n";
    print STDERR " \$this->\{index_options\}->\{compact_format\}  = $this->{index_options}->{compact_format}  \n";
    print STDERR " \$this->\{index_options\}->\{compound_header\} = $this->{index_options}->{compound_header} \n";
}

 
__END__

=head1 NAME

$Id: CDX.pm,v 1.4 2003/02/08 17:16:58 jettero Exp $

FoxPro::CDX - Perl extension for reading and writing foxpro index files

=head1 SYNOPSIS

This module is nowhere near done yet!  I have a bazillion plans for 
features in my todo list (which is not public).  If you have any feature 
requests do send them along.  Even if I don't implement them, I'd love to 
hear from you.

=head1 AUTHOR

Jettero Heller jettero@cpan.org

http://www.voltar.org

=head1 SEE ALSO

http://www.wotsit.org/

http://msdn.microsoft.com/library/default.asp?url=/library/en-us/fox7help/html/concompact_index_file_structure_lpidxrp.asp


perl(1)

=cut
